import "core-js/stable";
import "regenerator-runtime/runtime";
import Vue from "vue";

import Cookies from "js-cookie";

import Element from "element-ui";
import "./assets/styles/element-variables.scss";

import "@/assets/styles/index.scss"; // global css
import "@/assets/styles/ruoyi.scss"; // ruoyi css
import App from "./App";
import store from "./store";
import router from "./router";
import directive from "./directive"; // directive
import plugins from "./plugins"; // plugins
import {download} from "@/utils/request";
import allTools from "./plugins/allTools";

import "./assets/icons"; // icon
import "./permission"; // permission control
import {getDicts} from "@/api/system/dict/data";
import {getConfigKey, updateConfigByKey} from "@/api/system/config";
import {
  parseTime,
  resetForm,
  addDateRange,
  selectDictLabel,
  selectDictLabels,
  handleTree,
} from "@/utils/ruoyi";
// 分页组件
import Pagination from "@/components/Pagination";
// 自定义表格工具组件
import RightToolbar from "@/components/RightToolbar";
// 富文本组件
import Editor from "@/components/Editor";
// 文件上传组件
import FileUpload from "@/components/FileUpload";
// 图片上传组件
import ImageUpload from "@/components/ImageUpload";
// 图片上传组件
import LocalImageUpload from "@/components/LocalImageUpload";
// 图片预览组件
import ImagePreview from "@/components/ImagePreview";
// 字典标签组件
import DictTag from "@/components/DictTag";
// 头部标签组件
import VueMeta from "vue-meta";
// 字典数据组件
import DictData from "@/components/DictData";
// 富文本编辑器
import cusEditor from '@/views/components/cusEditor.vue'

import splitPane from 'vue-splitpane'

// 去除控制台的 Vue warn 警告信息
Vue.config.silent = true;

//自定义消息框
import ShowMsgBox from '@/utils/MsgBox'

//自定义组件
import invSelect from "@/views/components/invSelect/invSelect.vue";
import mainActionSelect from "@/views/components/mainActionSelect/index.vue";
import thirdSysSelect from "@/views/components/thirdSysSelect/index.vue";
import actionSelect from "@/views/components/actionSelect/index.vue";
import deptSelect from "@/views/components/deptSelect/index.vue";
import planChooseDevice from "@/views/components/planChooseDevice/index.vue";

import _ from "loadsh"
import winExtend from "@/winExtend.js";

// 全局方法挂载
Vue.prototype.getDicts = getDicts;
Vue.prototype.getConfigKey = getConfigKey;
Vue.prototype.updateConfigByKey = updateConfigByKey;
Vue.prototype.parseTime = parseTime;
Vue.prototype.resetForm = resetForm;
Vue.prototype.addDateRange = addDateRange;
Vue.prototype.selectDictLabel = selectDictLabel;
Vue.prototype.selectDictLabels = selectDictLabels;
Vue.prototype.download = download;
Vue.prototype.handleTree = handleTree;
Vue.prototype.openNewWindow = (url)=>{
    return window.open(url,'_blank',`width=1000,height=800,resizable=yes,scrollbars=yes,status=yes,menubar=no,toolbar=no,location=no,left=500,top=200`)
}

import deviceInfo from "@/views/dev/deviceInfo.vue";
import deviceRepairDialog from "@/views/components/deviceRepairDialog/index.vue";


// 全局组件挂载
Vue.component("DictTag", DictTag);
Vue.component("Pagination", Pagination);
Vue.component("RightToolbar", RightToolbar);
Vue.component("Editor", Editor);
Vue.component("FileUpload", FileUpload);
Vue.component("ImageUpload", ImageUpload);
Vue.component("LocalImageUpload", LocalImageUpload);
Vue.component("ImagePreview", ImagePreview);
Vue.component('split-pane', splitPane);
Vue.component("cusEditor", cusEditor)
Vue.component("invSelect", invSelect)
Vue.component("mainActionSelect", mainActionSelect)
Vue.component("thirdSysSelect", thirdSysSelect)
Vue.component("actionSelect", actionSelect)
Vue.component("deptSelect", deptSelect)
Vue.component("planChooseDevice", planChooseDevice)
Vue.component("deviceInfo", deviceInfo)
Vue.component("deviceRepairDialog", deviceRepairDialog)

Vue.use(directive);
Vue.use(plugins);
Vue.use(VueMeta);
Vue.use(allTools);
Vue.use(ShowMsgBox)
Vue.use(winExtend);
DictData.install();

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */

// 修改 el-dialog 默认点击遮照为不关闭
Element.Dialog.props.closeOnClickModal = {type: Boolean, default: false}
Element.Dialog.props.appendToBody = {type: Boolean, default: true}

Element.Table.props.border = {type: Boolean, default: true}
Element.Table.props.minHeight = {type: String | Number, default: "250"}
Element.Table.props.fit = {type: Boolean, default: true}
Element.Table.props.stripe = {type: Boolean, default: true}
Element.TableColumn.props.highlightCurrentRow	 = {type: Boolean, default: true}
Element.TableColumn.props.showOverflowTooltip = {type: Boolean, default: true}
Element.DatePicker.props.firstDayOfWeek = {type: Number, default: 1}
Element.Tag.props.effect = {type: String, default: 'dark'}


Element.Select.methods.deleteSelected =
  function deleteSelected(event) {
    event.stopPropagation()
    // 改动在这,原始的是这样  var value = this.multiple ? [] : ''
    var value = this.multiple ? [] : null
    this.$emit("input", value)
    this.emitChange(value)
    this.visible = false
    this.$emit("clear")
  }

Vue.use(Element, {
  size: Cookies.get("size") || "mini", // set element-ui default size
});

Vue.config.productionTip = false;

new Vue({
  el: "#app",
  router,
  store,
  render: (h) => h(App),
});
